pub fn sanitize_bytes(bytes: &mut [u8])
Volatile-clears an ordinary caller-owned byte buffer.
This delegates to the reviewed sanitization crate so the clear cannot be removed as an ordinary dead store.
sanitization